Crate synaptic_langfuse

Crate synaptic_langfuse 

Langfuse observability integration for Synaptic.

Langfuse is an open-source LLM observability platform. This crate provides a CallbackHandler that records all Synaptic run events to Langfuse traces.

Structs

LangfuseCallback
Callback handler that sends Synaptic run events to Langfuse.
LangfuseConfig
Configuration for the Langfuse callback.
LangfuseEvent
A single Langfuse event for the ingestion API.