Langfuse observability integration for Synaptic.
Langfuse is an open-source LLM observability platform. This crate provides a CallbackHandler that records all Synaptic run events to Langfuse traces.
Structs
- Langfuse
Callback - Callback handler that sends Synaptic run events to Langfuse.
- Langfuse
Config - Configuration for the Langfuse callback.
- Langfuse
Event - A single Langfuse event for the ingestion API.